/****************************************************************************

  (c) SYSTEC electronic GmbH, D-07973 Greiz, August-Bebel-Str. 29
      www.systec-electronic.de

  Project:      X

  Description:  Abstract Memory Interface for ARM7 compiler

  -------------------------------------------------------------------------

                $RCSfile: amiarm7.c,v $

                $Author: R.Dietzsch $

                $Revision: 1.10 $  $Date: 2007/07/30 08:47:06 $

                $State: Exp $

                Build Environment:
                    ...

  -------------------------------------------------------------------------

  Revision History:

    15.02.2008  r.d.:
        - Cleanings for USB-CANmodul under WinCE.
        - AmiSetSwapWord(), AmiSetSwapDword(), AmiGetSwapWord() and AmiGetSwapDword() added

****************************************************************************/

#include "global.h"

//---------------------------------------------------------------------------
//  defines for different ARM compilers
//---------------------------------------------------------------------------


//---------------------------------------------------------------------------
//  Typdefinitionen
//---------------------------------------------------------------------------


#define AMI_READ_BYTE(ptr,offs)             (*((BYTE FAR*) (ptr) + (offs)))
#define AMI_WRITE_BYTE(ptr,offs,val)        (*((BYTE FAR*) (ptr) + (offs))) = (BYTE) (val)



//------------< Word auf absoluter Adresse setzen >--------------------------

void  PUBLIC  AmiSetWord (void FAR* pAddr_p, WORD wWordVal_p)
{

// Diese Funktion dient zum Schreiben eines Words auf der angegebenen
// absoluten Adresse. Die Funktionen der Gruppe <AmiSetxxx> werden verwendet,
// um Daten zum Austausch mit anderen Systemen im Intel-Format abzulegen.


    AMI_WRITE_BYTE (pAddr_p, 0, wWordVal_p);
    wWordVal_p >>= 8;
    AMI_WRITE_BYTE (pAddr_p, 1, wWordVal_p);

}

void  PUBLIC  AmiSetSwapWord (void FAR* pAddr_p, WORD wWordVal_p)
{

    AMI_WRITE_BYTE (pAddr_p, 1, wWordVal_p);
    wWordVal_p >>= 8;
    AMI_WRITE_BYTE (pAddr_p, 0, wWordVal_p);

}



//------------< Dword auf absoluter Adresse setzen >-------------------------

void  PUBLIC  AmiSetDword (void FAR* pAddr_p, DWORD dwDwordVal_p)
{

// Diese Funktion dient zum Schreiben eines Dwords auf der angegebenen
// absoluten Adresse. Die Funktionen der Gruppe <AmiSetxxx> werden verwendet,
// um Daten zum Austausch mit anderen Systemen im Intel-Format abzulegen.


    AMI_WRITE_BYTE (pAddr_p, 0, dwDwordVal_p);
    dwDwordVal_p >>= 8;
    AMI_WRITE_BYTE (pAddr_p, 1, dwDwordVal_p);
    dwDwordVal_p >>= 8;
    AMI_WRITE_BYTE (pAddr_p, 2, dwDwordVal_p);
    dwDwordVal_p >>= 8;
    AMI_WRITE_BYTE (pAddr_p, 3, dwDwordVal_p);

}

void  PUBLIC  AmiSetSwapDword (void FAR* pAddr_p, DWORD dwDwordVal_p)
{

    AMI_WRITE_BYTE (pAddr_p, 3, dwDwordVal_p);
    dwDwordVal_p >>= 8;
    AMI_WRITE_BYTE (pAddr_p, 2, dwDwordVal_p);
    dwDwordVal_p >>= 8;
    AMI_WRITE_BYTE (pAddr_p, 1, dwDwordVal_p);
    dwDwordVal_p >>= 8;
    AMI_WRITE_BYTE (pAddr_p, 0, dwDwordVal_p);

}


//------------< Word von absoluter Adresse lesen >---------------------------

WORD  PUBLIC  AmiGetWord (void FAR* pAddr_p)
{

// Diese Funktion dient zum Lesen eines Words von der angegebenen absoluten
// Adresse. Die Funktionen der Gruppe <AmiGetxxx> werden verwendet, um Daten,
// die mit einem anderen System ausgetauscht wurden und im Intel-Format abge-
// legt sind, zu lesen.


WORD wValue;

    wValue   = (WORD) AMI_READ_BYTE (pAddr_p, 1);
    wValue <<= 8;
    wValue  |= (WORD) AMI_READ_BYTE (pAddr_p, 0);

    return ( wValue );

}

WORD  PUBLIC  AmiGetSwapWord (void FAR* pAddr_p)
{

WORD wValue;

    wValue   = (WORD) AMI_READ_BYTE (pAddr_p, 0);
    wValue <<= 8;
    wValue  |= (WORD) AMI_READ_BYTE (pAddr_p, 1);

    return ( wValue );

}



//------------< Dword von absoluter Adresse lesen >--------------------------

DWORD  PUBLIC  AmiGetDword (void FAR* pAddr_p)
{

// Diese Funktion dient zum Lesen eines Dwords von der angegebenen absoluten
// Adresse. Die Funktionen der Gruppe <AmiGetxxx> werden verwendet, um Daten,
// die mit einem anderen System ausgetauscht wurden und im Intel-Format abge-
// legt sind, zu lesen.


DWORD dwValue;

    dwValue   = (DWORD) AMI_READ_BYTE (pAddr_p, 3);
    dwValue <<= 8;
    dwValue  |= (DWORD) AMI_READ_BYTE (pAddr_p, 2);
    dwValue <<= 8;
    dwValue  |= (DWORD) AMI_READ_BYTE (pAddr_p, 1);
    dwValue <<= 8;
    dwValue  |= (DWORD) AMI_READ_BYTE (pAddr_p, 0);

    return ( dwValue );

}

DWORD  PUBLIC  AmiGetSwapDword (void FAR* pAddr_p)
{

DWORD dwValue;

    dwValue   = (DWORD) AMI_READ_BYTE (pAddr_p, 0);
    dwValue <<= 8;
    dwValue  |= (DWORD) AMI_READ_BYTE (pAddr_p, 1);
    dwValue <<= 8;
    dwValue  |= (DWORD) AMI_READ_BYTE (pAddr_p, 2);
    dwValue <<= 8;
    dwValue  |= (DWORD) AMI_READ_BYTE (pAddr_p, 3);

    return ( dwValue );

}


